[][src]Struct conec::client::Client

pub struct Client { /* fields omitted */ }

The Client end of a connection to the Coordinator

See library documentation for an example of constructing a Client.

Implementations

impl Client[src]

pub async fn new(
    config: ClientConfig
) -> Result<(Self, IncomingStreams), ClientError>
[src]

Construct a Client and connect to the Coordinator

pub fn new_stream(
    &self,
    to: String,
    cid: u32
) -> Result<ConnectingOutStream, ClientChanError>
[src]

Open a new stream to another client, proxied through the Coordinator