[−][src]Struct conec::client::Client
The Client end of a connection to the Coordinator
See library documentation for an example of constructing a Client.
Implementations
impl Client[src]
pub async fn new(
config: ClientConfig
) -> Result<(Self, IncomingStreams), ClientError>[src]
config: ClientConfig
) -> Result<(Self, IncomingStreams), ClientError>
Construct a Client and connect to the Coordinator
pub fn new_stream(
&self,
to: String,
cid: u32
) -> Result<ConnectingOutStream, ClientChanError>[src]
&self,
to: String,
cid: u32
) -> Result<ConnectingOutStream, ClientChanError>
Open a new stream to another client, proxied through the Coordinator